@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: add.py 962 2008-07-18 15:19:29Z mikej06 $'
+__revision__ = '$Id: add.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -21,7 +21,6 @@ __revision__ = '$Id: add.py 962 2008-07-18 15:19:29Z mikej06 $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import gutils
 import os
 import gtk
@@ -235,33 +234,33 @@ def get_details(self): #{{{
 	plot_buffer  = w['plot'].get_buffer()
 	
 	t_movies = {
-		'classification' : w['classification'].get_text(),
+		'classification' : w['classification'].get_text().decode('utf-8'),
 		'color'          : w['color'].get_active(),
 		'cond'           : w['condition'].get_active(),
-		'country'        : w['country'].get_text(),
-		'director'       : w['director'].get_text(),
-		'genre'          : w['genre'].get_text(),
-		'image'          : w['image'].get_text(),
+		'country'        : w['country'].get_text().decode('utf-8'),
+		'director'       : w['director'].get_text().decode('utf-8'),
+		'genre'          : w['genre'].get_text().decode('utf-8'),
+		'image'          : w['image'].get_text().decode('utf-8'),
 		'layers'         : w['layers'].get_active(),
 		'media_num'      : w['discs'].get_value(),
 		'number'         : w['number'].get_value(),
-		'o_site'         : w['o_site'].get_text(),
-		'o_title'        : w['o_title'].get_text(),
+		'o_site'         : w['o_site'].get_text().decode('utf-8'),
+		'o_title'        : w['o_title'].get_text().decode('utf-8'),
 		'rating'         : w['rating_slider'].get_value(),
 		'region'         : w['region'].get_active(),
-		'runtime'        : w['runtime'].get_text(),
-		'site'           : w['site'].get_text(),
-		'studio'         : w['studio'].get_text(),
-		'title'          : w['title'].get_text(),
-		'trailer'        : w['trailer'].get_text(),
+		'runtime'        : w['runtime'].get_text().decode('utf-8'),
+		'site'           : w['site'].get_text().decode('utf-8'),
+		'studio'         : w['studio'].get_text().decode('utf-8'),
+		'title'          : w['title'].get_text().decode('utf-8'),
+		'trailer'        : w['trailer'].get_text().decode('utf-8'),
 		'year'           : w['year'].get_value(),
 		'collection_id'  : w['collection'].get_active(),
 		'medium_id'      : w['media'].get_active(),
 		'volume_id'      : w['volume'].get_active(),
 		'vcodec_id'      : w['vcodec'].get_active(),
-		'cast'           : cast_buffer.get_text(cast_buffer.get_start_iter(),cast_buffer.get_end_iter()),
-		'notes'          : notes_buffer.get_text(notes_buffer.get_start_iter(),notes_buffer.get_end_iter()),
-		'plot'           : plot_buffer.get_text(plot_buffer.get_start_iter(),plot_buffer.get_end_iter()),
+		'cast'           : cast_buffer.get_text(cast_buffer.get_start_iter(),cast_buffer.get_end_iter()).decode('utf-8'),
+		'notes'          : notes_buffer.get_text(notes_buffer.get_start_iter(),notes_buffer.get_end_iter()).decode('utf-8'),
+		'plot'           : plot_buffer.get_text(plot_buffer.get_start_iter(),plot_buffer.get_end_iter()).decode('utf-8'),
 	}
 	if self._am_movie_id is not None:
 		t_movies['movie_id'] = self._am_movie_id
@@ -332,7 +331,10 @@ def validate_details(t_movies, allow_only=None):
 				t_movies.pop(i)
 
 def update_movie(self):
-	movie = self.db.Movie.get_by(movie_id=self._movie_id)
+	if self._am_movie_id is not None:
+		movie = self.db.Movie.get_by(movie_id=self._am_movie_id)
+	else:
+		movie = self.db.Movie.get_by(movie_id=self._movie_id)
 	if movie is None: # movie was deleted in the meantime
 		return add_movie_db(self, True)
 	old_image = movie.image
@@ -372,6 +374,10 @@ def update_movie(self):
 			tmp_model.set_value(tmp_iter,8, '')
 		else:
 			tmp_model.set_value(tmp_iter,8, '%003d' % int(movie.runtime) + _(' min'))
+		if movie.rating is None:
+			tmp_model.set_value(tmp_iter,9, '')
+		else:
+			tmp_model.set_value(tmp_iter,9, movie.rating)
 		# close add window
 		self.widgets['add']['window'].hide()
 		# refresh
@@ -440,6 +446,10 @@ def add_movie_db(self, close):
 		self.treemodel.set_value(myiter, 8, '')
 	else:
 		self.treemodel.set_value(myiter, 8, '%003d' % int(details['runtime']) + _(' min'))
+	if details['rating'] is None:
+		self.treemodel.set_value(myiter, 9, '')
+	else:
+		self.treemodel.set_value(myiter, 9, details['rating'])
 	#update statusbar
 	self.total += 1
 	self.count_statusbar()
@@ -486,6 +496,8 @@ def populate_with_results(self):
 	plugin = __import__(plugin_name)
 	self.movie = plugin.Plugin(m_id)
 	self.movie.locations = self.locations
+	self.movie.debug = self.debug
+	self.movie.config = self.config
 	
 	fields_to_fetch = ['o_title', 'title', 'director', 'plot', 'cast', 'country', 'genre',
 				'classification', 'studio', 'o_site', 'site', 'trailer', 'year',
@@ -498,7 +510,7 @@ def populate_with_results(self):
 		fields_to_fetch = [ i for i in fields_to_fetch if details[i] is None ]
 	self.movie.fields_to_fetch = fields_to_fetch
 	
-	self.movie.open_page(w['window'])
+	self.movie.get_movie(w['window'])
 	self.movie.parse_movie()
 
 	if 'year' in fields_to_fetch:
@@ -585,6 +597,8 @@ def get_from_web(self):
 		plugin_name = 'PluginMovie%s' % option
 		plugin = __import__(plugin_name)
 		self.search_movie = plugin.SearchPlugin()
+		self.search_movie.debug = self.debug
+		self.search_movie.config = self.config
 		if o_title:
 			self.search_movie.url = self.search_movie.original_url_search
 			if self.search_movie.remove_accents:
@@ -597,7 +611,7 @@ def get_from_web(self):
 				self.search_movie.title = gutils.remove_accents(title, 'utf-8')
 			else:
 				self.search_movie.title = unicode(title, 'utf-8')
-		self.search_movie.search(self.widgets['add']['window'])
+		self.search_movie.search_movies(self.widgets['add']['window'])
 		self.search_movie.get_searches()
 		if len(self.search_movie.ids) == 1 and o_title and title:
 			self.search_movie.url = self.search_movie.translated_url_search
@@ -605,7 +619,7 @@ def get_from_web(self):
 				self.search_movie.title = gutils.remove_accents(title, 'utf-8')
 			else:
 				self.search_movie.title = unicode(title, 'utf-8')
-			self.search_movie.search(self.widgets['add']['window'])
+			self.search_movie.search_movies(self.widgets['add']['window'])
 			self.search_movie.get_searches()
 		self.show_search_results(self.search_movie)
 	else:
