@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: gemail.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: gemail.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 
@@ -24,7 +24,6 @@ __revision__ = '$Id: gemail.py 891 2007-12-16 21:13:53Z piotrek $'
 import socket
 import smtplib
 import gutils
-from gettext import gettext as _
 
 socket.setdefaulttimeout(10)
 
@@ -77,8 +76,8 @@ def send_email(self):
 				_("Movie loan reminder"), _("Hi, %s!\n\nJust to remind you " + \
 				"that I'm really needing the following movie I have loaned to you " + \
 				"recently:\n\n%s (%s)\n\nLoaned on %s") \
-				%(self.person_name, self.widgets['movie']['o_title'].get_text(), \
-				self.widgets['movie']['title'].get_text(), self.loan_date[:10]))
+				%(self.person_name, self.widgets['movie']['o_title'].get_text().decode('utf-8'), \
+				self.widgets['movie']['title'].get_text().decode('utf-8'), self.loan_date[:10]))
 		except:
 			gutils.error(self, _("Mail could not be sent. Please check e-mail preferences."), self.widgets['window'])
 	else:
