@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: initialize.py 966 2008-07-24 20:42:36Z mikej06 $'
+__revision__ = '$Id: initialize.py 1038 2008-11-15 20:16:06Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -30,7 +30,7 @@ import gobject
 import gettext
 import platform
 import re
-from gettext import gettext as _
+import gettext
 from locale import getdefaultlocale
 
 try:
@@ -171,6 +171,7 @@ def i18n(self, location):
 	gettext.textdomain('griffith')
 	gtk.glade.bindtextdomain('griffith', location)
 	gtk.glade.textdomain('griffith')
+	gettext.install('griffith', location, unicode=1)
 
 def toolbar(self):
 	"""if toolbar is hide in config lets hide the widget"""
@@ -711,6 +712,8 @@ def preferences(self):
 		self.widgets['preferences']['db_type'].set_active(0)
 
 def fill_volumes_combo(self, default=0):
+	_tmp = self.initialized
+	self.initialized = False # don't refresh main treeview
 	self.widgets['add']['volume'].get_model().clear()
 	self.widgets['filter']['volume'].get_model().clear()
 	for i in self.volume_combo_ids:
@@ -719,9 +722,10 @@ def fill_volumes_combo(self, default=0):
 			name = self.db.Volume.get_by(volume_id=vol_id).name
 		else:
 			name = ''
+		self.widgets['add']['volume'].insert_text(int(i), str(name))
 		# add some white spaces to prevent scrollbar hides parts of the names	
-		self.widgets['add']['volume'].insert_text(int(i), str(name) + '   ')
 		self.widgets['filter']['volume'].insert_text(int(i), str(name) + '   ')
+	self.initialized = _tmp
 	self.widgets['add']['volume'].show_all()
 	self.widgets['filter']['volume'].show_all()
 	self.widgets['filter']['volume'].set_active(0)
@@ -731,6 +735,8 @@ def fill_volumes_combo(self, default=0):
 	self.widgets['add']['volume'].set_wrap_width(3)
 
 def fill_collections_combo(self, default=0):
+	_tmp = self.initialized
+	self.initialized = False # don't refresh main treeview
 	self.widgets['add']['collection'].get_model().clear()
 	self.widgets['filter']['collection'].get_model().clear()
 	for i in self.collection_combo_ids:
@@ -739,9 +745,11 @@ def fill_collections_combo(self, default=0):
 			name = self.db.Collection.get_by(collection_id=col_id).name
 		else:
 			name = ''
+		self.widgets['add']['collection'].insert_text(int(i), str(name))
 		# add some white spaces to prevent scrollbar hides parts of the names	
-		self.widgets['add']['collection'].insert_text(int(i), str(name) + '   ')
 		self.widgets['filter']['collection'].insert_text(int(i), str(name) + '   ')
+	self.initialized = _tmp
+	self.initialized = False
 	self.widgets['add']['collection'].show_all()
 	self.widgets['filter']['collection'].show_all()
 	self.widgets['filter']['collection'].set_active(0)
@@ -751,6 +759,8 @@ def fill_collections_combo(self, default=0):
 	self.widgets['add']['collection'].set_wrap_width(2)
 
 def fill_loanedto_combo(self):
+	_tmp = self.initialized
+	self.initialized = False # don't refresh main treeview
 	self.widgets['filter']['loanedto'].get_model().clear()
 	for i in self.loanedto_combo_ids:
 		per_id = self.loanedto_combo_ids[i]
@@ -760,10 +770,13 @@ def fill_loanedto_combo(self):
 			name = ''
 		# add some white spaces to prevent scrollbar hides parts of the names	
 		self.widgets['filter']['loanedto'].insert_text(int(i), str(name) + '   ')
+	self.initialized = _tmp
 	self.widgets['filter']['loanedto'].show_all()
 	self.widgets['filter']['loanedto'].set_active(0)
 
 def fill_bytag_combo(self):
+	_tmp = self.initialized
+	self.initialized = False # don't refresh main treeview
 	self.widgets['filter']['tag'].get_model().clear()
 	for i in self.bytag_combo_ids:
 		id = self.bytag_combo_ids[i]
@@ -773,10 +786,13 @@ def fill_bytag_combo(self):
 			name = ''
 		# add some white spaces to prevent scrollbar hides parts of the names	
 		self.widgets['filter']['tag'].insert_text(int(i), str(name) + '   ')
+	self.initialized = _tmp
 	self.widgets['filter']['tag'].show_all()
 	self.widgets['filter']['tag'].set_active(0)
 
 def fill_preferences_tags_combo(self):
+	_tmp = self.initialized
+	self.initialized = False # don't refresh main treeview
 	self.widgets['preferences']['tag_name'].get_model().clear()
 	self.tags_ids = {}
 	i = 0
@@ -784,6 +800,7 @@ def fill_preferences_tags_combo(self):
 		self.tags_ids[i] = tag.tag_id
 		self.widgets['preferences']['tag_name'].insert_text(int(i), str(tag.name))
 		i += 1
+	self.initialized = _tmp
 	self.widgets['preferences']['tag_name'].show_all()
 
 def language_combos(self):
