@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: main_treeview.py 967 2008-07-25 10:02:27Z mikej06 $'
+__revision__ = '$Id: main_treeview.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 
@@ -21,7 +21,6 @@ __revision__ = '$Id: main_treeview.py 967 2008-07-25 10:02:27Z mikej06 $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import gutils
 import os
 import gtk
@@ -492,11 +491,11 @@ def populate(self, movies=None, where=None):#{{{
 		self.treemodel.set_value(myiter,4,movie.director)
 		self.treemodel.set_value(myiter,5,movie.genre)
 		self.treemodel.set_value(myiter,6,movie.seen)
-		if movie.year is not None and movie.year is int:
+		if movie.year is not None and isinstance(movie.year, int):
 			self.treemodel.set_value(myiter,7,movie.year)
-		if movie.runtime is not None and movie.runtime is int:
+		if movie.runtime is not None and isinstance(movie.runtime, int):
 			self.treemodel.set_value(myiter,8, '%003d' % movie.runtime + _(' min'))
-		if movie.rating is not None and movie.rating is int:
+		if movie.rating is not None and isinstance(movie.rating, int):
 			self.treemodel.set_value(myiter,9,movie.rating)
 		
 	# restore user sort column
