@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: PluginExportHTML.py 963 2008-07-21 20:03:51Z piotrek $'
+__revision__ = '$Id: PluginExportHTML.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2007 Piotr Ożarowski
 #
@@ -30,7 +30,6 @@ import glob, shutil
 import version
 import math
 from xml.dom import minidom
-from gettext import gettext as _
 
 plugin_name         = 'HTML'
 plugin_description  = _('Plugin exports data using templates')
@@ -466,10 +465,12 @@ class ExportPlugin(gtk.Window):
 	def on_combo_style_changed(self, widget):
 		self.config['style'] = widget.get_active()
 		self.widgets['cb_custom_style'].set_active(False)
+		preview_file = None
 
 		tpl_id = self.config['template']
 		template_dir = os.path.join(self.locations['share'], 'export_templates', self.templates[tpl_id]['dir'])
-		preview_file = self.templates[self.config['template']]['styles'][self.config['style']]['preview']
+		if self.config['style'] > -1:
+			preview_file = self.templates[self.config['template']]['styles'][self.config['style']]['preview']
 		if preview_file is not None:
 			preview_file = os.path.join(template_dir, preview_file)
 		if preview_file is not None and not os.path.isfile(preview_file):
@@ -621,8 +622,8 @@ class ExportPlugin(gtk.Window):
 		
 		# get data from widgets
 		self.config['exported_dir'] = self.widgets['fcw'].get_filename()
-		self.config['title']        = self.widgets['entry_header'].get_text()
-		self.config['sorting']      = self.names[self.widgets['combo_sortby'].get_active_text()]
+		self.config['title']        = self.widgets['entry_header'].get_text().decode('utf-8')
+		self.config['sorting']      = self.names[self.widgets['combo_sortby'].get_active_text().decode('utf-8')]
 		if self.widgets['cb_reverse'].get_active():
 			self.config['sorting2'] = 'DESC'
 		else:
