@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportPDF.py 949 2008-05-10 20:41:52Z mikej06 $'
+__revision__ = '$Id: PluginExportPDF.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 #
@@ -21,7 +21,6 @@ __revision__ = '$Id: PluginExportPDF.py 949 2008-05-10 20:41:52Z mikej06 $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 from reportlab.pdfgen import canvas
 from reportlab.lib.pagesizes import letter, A4
 from reportlab.lib.units import mm, inch
@@ -75,7 +74,7 @@ class ExportPlugin:
             filename = gutils.file_chooser(_("Export a PDF"), action=gtk.FILE_CHOOSER_ACTION_SAVE, buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name="griffith_simple_list.pdf")
         else:
             filename = gutils.file_chooser(_("Export a PDF"), action=gtk.FILE_CHOOSER_ACTION_SAVE, buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name="griffith_simple_list.pdf",folder=basedir)
-        if filename[0]:
+        if filename is not False and filename[0]:
             if not self.config is None and filename[1]:
                 self.config.set('export_dir', filename[1], section='export-pdf')
                 self.config.save()
@@ -95,10 +94,10 @@ class ExportPlugin:
                     defaultEnc = 'UTF-8'
                 c = SimpleDocTemplate(pdffilename.encode(defaultEnc))
                 # data encoding
-                if defaultEncoding == 'WinAnsiEncoding':
-                    defaultEnc = 'cp1252'
-                else:
-                    defaultEnc = 'utf-8'
+                #if defaultEncoding == 'WinAnsiEncoding':
+                #    defaultEnc = 'cp1252'
+                #else:
+                defaultEnc = 'utf-8'
                 style = self.styles["Normal"]
                 Story = [Spacer(1,2*inch)]
                 # define some custom stylesheetfont
@@ -113,7 +112,10 @@ class ExportPlugin:
                 # select sort column
                 sort_column_name = self.config.get('sortby', 'number', section='mainlist')
                 sort_reverse = self.config.get('sortby_reverse', False, section='mainlist')
+                do_grouping = True
                 for i in sort_column_name.split(','):
+                    if i != 'title' and i != 'o_title':
+                        do_grouping = False
                     if self.db.Movie.c.has_key(i):
                         if sort_reverse:
                             movies.order_by_clause.append(desc(self.db.Movie.c[i]))
@@ -130,11 +132,19 @@ class ExportPlugin:
                     else:
                         director = ""
                     # group by first letter
-                    if title[0] != first_letter:
-                        first_letter = title[0]
-                        paragraph_text = '<font name=' + self.fontName + ' size="15">' + saxutils.escape(first_letter) + '</fonts>'
-                        p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Heading2'])
-                        Story.append(p)
+                    if do_grouping and title[0] != first_letter:
+                        if title[0] in '0123456789':
+                            # Group Numbers
+                            if first_letter != '0-9':
+                                first_letter = '0-9'
+                                paragraph_text = '<font name=' + self.fontName + ' size="15">' + saxutils.escape(first_letter) + '</fonts>'
+                                p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Heading2'])
+                                Story.append(p)
+                        else:
+                            first_letter = title[0]
+                            paragraph_text = '<font name=' + self.fontName + ' size="15">' + saxutils.escape(first_letter) + '</fonts>'
+                            p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Heading2'])
+                            Story.append(p)
                     # add movie title
                     paragraph_text = '<font name=' + self.fontName + ' size="7">' + \
                         '<b>'+ saxutils.escape(title) + '</b>' + \
