@@ -21,7 +21,6 @@ __revision__ = '$Id: PluginMovie7arte.py 478 2006-12-05 21:14:51Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import gutils
 import movie
 import string
@@ -56,7 +55,7 @@ class Plugin(movie.Movie):
 
 	def get_director(self):
 		"""Finds the film's director"""
-		self.director = gutils.strip_tags(gutils.trim(self.page, "<div><b>Realizao:</b><br>", "</div>"))
+		self.director = gutils.strip_tags(gutils.trim(self.page, "<div><b>Realização:</b><br>", "</div>"))
 		self.director = string.replace(self.director,"<br>", ", ")
 		self.director = gutils.strip_tags(self.director)
 
@@ -70,11 +69,11 @@ class Plugin(movie.Movie):
 
 	def get_runtime(self):
 		"""Finds the film's running time"""
-		self.runtime = gutils.trim(self.page, "<td><b>Durao:</b> ", " min.</td>")
+		self.runtime = gutils.trim(self.page, "<td><b>Duração:</b> ", " min.</td>")
 
 	def get_genre(self):
 		"""Finds the film's genre"""
-		self.genre = gutils.strip_tags(gutils.trim(self.page, "<b>Gnero:</b><br>", "</div>"))
+		self.genre = gutils.strip_tags(gutils.trim(self.page, "<b>Género:</b><br>", "</div>"))
 		self.genre = string.replace(self.genre,"<br>", ", ")
 		self.genre = gutils.strip_tags(self.genre)
 
@@ -96,13 +95,13 @@ class Plugin(movie.Movie):
 		"""Find the film's oficial site"""
 		self.o_site = gutils.trim(self.page, \
 			"<a class=\"button\" href=\"", \
-			" title=\"Consultar ttulo no Internet Movie Data Base\"")
+			" title=\"Consultar título no Internet Movie Data Base\"")
 
 	def get_site(self):
 		"""Find the film's imdb details page"""
 		self.site = gutils.trim(self.page, \
 			"</td><td><a class=\"button\" href=\"", \
-			"""" title="Consultar título""")
+			"""" title="Consultar tÃ­tulo""")
 
 	def get_trailer(self):
 		"""Find the film's trailer page or location"""
@@ -110,7 +109,7 @@ class Plugin(movie.Movie):
 
 	def get_country(self):
 		"""Find the film's country"""
-		self.country = gutils.trim(self.page, "<b>Pas:</b><br>", "</div>")
+		self.country = gutils.trim(self.page, "<b>País:</b><br>", "</div>")
 		self.country = string.replace(self.country,"<br>", ", ")
 		self.country = gutils.strip_tags(self.country)
 
