@@ -7,7 +7,6 @@ __revision__ = '$Id$'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import gutils
 import movie,string,re
 
@@ -127,6 +126,7 @@ class SearchPlugin(movie.SearchMovie):
 		self.original_url_search   = "http://www.ofdb.de/view.php?page=suchergebnis&Kat=OTitel&SText="
 		self.translated_url_search = "http://www.ofdb.de/view.php?page=suchergebnis&Kat=DTitel&SText="
 		self.encode='utf-8'
+		self.remove_accents = False
 
 	def search(self,parent_window):
 		self.open_search(parent_window)
@@ -157,12 +157,12 @@ class SearchPlugin(movie.SearchMovie):
 class SearchPluginTest(SearchPlugin):
 	#
 	# Configuration for automated tests:
-	# dict { movie_id -> expected result count }
+	# dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
 	#
 	test_configuration = {
-		'Rocky Balboa'			: 1,
-		'Arahan'				: 3,
-		'glückliches'			: 2
+		'Rocky Balboa'			: [ 1, 1 ],
+		'Arahan'				: [ 3, 2 ],
+		'glückliches'			: [ 4, 2 ]
 	}
 
 class PluginTest:
