@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMoviePTGate.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: PluginMoviePTGate.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes, Piotr Ozarowski
 #
@@ -21,7 +21,6 @@ __revision__ = '$Id: PluginMoviePTGate.py 891 2007-12-16 21:13:53Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import gutils
 import movie
 import string
@@ -50,7 +49,7 @@ class Plugin(movie.Movie):
 		self.title = string.capwords(gutils.trim(self.page,"class=subtitle>","</b><br>") )
 
 	def get_director(self):
-		self.director = gutils.trim(self.page,"<b>realizao</b><br>","<br><br><b>")
+		self.director = gutils.trim(self.page,"<b>realização</b><br>","<br><br><b>")
 
 	def get_plot(self):
 		self.plot = gutils.trim(self.page,"<b>sinopse</b><br>","<br><br>")
@@ -93,7 +92,7 @@ class Plugin(movie.Movie):
 		self.country = gutils.trim(self.page,"s</b><br>","<br><br><b>g")
 		
 	def get_notes(self):
-		self.notes = gutils.trim(self.page,"prmios e nomeaes</b><br><b>", "<td width=6 background='Images/group_r.gif'")
+		self.notes = gutils.trim(self.page,"prémios e nomeações</b><br><b>", "<td width=6 background='Images/group_r.gif'")
 		self.notes = gutils.strip_tags(self.notes)
 
 	def get_rating(self):
