@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: quick_filter.py 951 2008-07-11 18:52:03Z mikej06 $'
+__revision__ = '$Id: quick_filter.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 
@@ -21,12 +21,11 @@ __revision__ = '$Id: quick_filter.py 951 2008-07-11 18:52:03Z mikej06 $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 import gutils
 
 def change_filter(self):
 	x = 0
-	text = gutils.gescape(self.widgets['filter']['text'].get_text())
+	text = gutils.gescape(self.widgets['filter']['text'].get_text().decode('utf-8'))
 	
 	from sqlalchemy import select
 	statement = select(self.db.Movie.c)
