@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: sql.py 908 2008-01-27 23:03:39Z piotrek $'
+__revision__ = '$Id: sql.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -21,7 +21,6 @@ __revision__ = '$Id: sql.py 908 2008-01-27 23:03:39Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 from sqlalchemy import *
 import os.path
 import gutils
@@ -496,11 +495,16 @@ class GriffithSQL:
 			debug.show("DB version: %s" % e)
 			v = 0
 
-		if v is not None and v>1:
+		if v is not None and v > 1:
 			v = int(v.value)
 		if v < self.version:
 			from dbupgrade import upgrade_database
-			upgrade_database(self, v)
+			if not upgrade_database(self, v):
+				raise Exception("cannot upgrade database")
+		elif v > self.version:
+			debug.show("database version mismatch (detacted:%s; current:%s)" % (v, self.version))
+			gutils.warning(self, _('This database requires newer version of Griffith.'))
+			raise Exception("database version mismatch")
 
 # for debugging (run: ipython sql.py)
 if __name__ == '__main__':
