@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: version.py 968 2008-07-26 20:17:42Z piotrek $'
+__revision__ = '$Id: version.py 1040 2008-11-15 21:13:49Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -21,9 +21,8 @@ __revision__ = '$Id: version.py 968 2008-07-26 20:17:42Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from gettext import gettext as _
 pname        = "Griffith"
-pversion     = "0.9.7.1"
+pversion     = "0.9.8"
 pauthor      = "Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>"
 pyear        = "2005-2008"
 pwebsite     = "http://www.griffith.cc/"
