@@ -54,11 +54,11 @@ opts = {
 
 setup(
     name = "Griffith",
-    version = "0.9.7.1",
+    version = "0.9.8",
 	description = 'Griffith - A film manager',
     author = 'Vasco Nunes/Piotr Ozarowski',
     author_email = 'vasco.m.nunes@gmail.com',
-    url = 'http://griffith.cc/',
+    url = 'http://www.griffith.cc/',
     license = 'GPL',
     windows = [
         {
@@ -81,18 +81,32 @@ setup(
 		("i18n/da/LC_MESSAGES",	glob.glob("i18n\\da\\LC_MESSAGES\\*.mo")),
 		("i18n/de/LC_MESSAGES",	glob.glob("i18n\\de\\LC_MESSAGES\\*.mo")),
 		("i18n/el/LC_MESSAGES",	glob.glob("i18n\\el\\LC_MESSAGES\\*.mo")),
+		("i18n/en_GB/LC_MESSAGES", glob.glob("i18n\\en_GB\\LC_MESSAGES\\*.mo")),
 		("i18n/es/LC_MESSAGES",	glob.glob("i18n\\es\\LC_MESSAGES\\*.mo")),
-		("i18n/ja/LC_MESSAGES",	glob.glob("i18n\\ja\\LC_MESSAGES\\*.mo")),
+		("i18n/et/LC_MESSAGES",	glob.glob("i18n\\et\\LC_MESSAGES\\*.mo")),
+		("i18n/fa/LC_MESSAGES",	glob.glob("i18n\\fa\\LC_MESSAGES\\*.mo")),
+		("i18n/fi/LC_MESSAGES",	glob.glob("i18n\\fi\\LC_MESSAGES\\*.mo")),
 		("i18n/fr/LC_MESSAGES",	glob.glob("i18n\\fr\\LC_MESSAGES\\*.mo")),
-		("i18n/nb/LC_MESSAGES",	glob.glob("i18n\\nb\\LC_MESSAGES\\*.mo")),
-		("i18n/pl/LC_MESSAGES",	glob.glob("i18n\\pl\\LC_MESSAGES\\*.mo")),
-		("i18n/pt/LC_MESSAGES",	glob.glob("i18n\\pt\\LC_MESSAGES\\*.mo")),
-		("i18n/ru/LC_MESSAGES",	glob.glob("i18n\\ru\\LC_MESSAGES\\*.mo")),
+		("i18n/hu/LC_MESSAGES",	glob.glob("i18n\\hu\\LC_MESSAGES\\*.mo")),
+		("i18n/id/LC_MESSAGES",	glob.glob("i18n\\id\\LC_MESSAGES\\*.mo")),
 		("i18n/it/LC_MESSAGES",	glob.glob("i18n\\it\\LC_MESSAGES\\*.mo")),
+		("i18n/ja/LC_MESSAGES",	glob.glob("i18n\\ja\\LC_MESSAGES\\*.mo")),
+		("i18n/ko/LC_MESSAGES",	glob.glob("i18n\\ko\\LC_MESSAGES\\*.mo")),
+		("i18n/lv/LC_MESSAGES",	glob.glob("i18n\\lv\\LC_MESSAGES\\*.mo")),
+		("i18n/nb/LC_MESSAGES",	glob.glob("i18n\\nb\\LC_MESSAGES\\*.mo")),
+		("i18n/nds/LC_MESSAGES",	glob.glob("i18n\\nds\\LC_MESSAGES\\*.mo")),
 		("i18n/nl/LC_MESSAGES",	glob.glob("i18n\\nl\\LC_MESSAGES\\*.mo")),
+		("i18n/oc/LC_MESSAGES",	glob.glob("i18n\\oc\\LC_MESSAGES\\*.mo")),
+		("i18n/pl/LC_MESSAGES",	glob.glob("i18n\\pl\\LC_MESSAGES\\*.mo")),
+		("i18n/ps/LC_MESSAGES",	glob.glob("i18n\\ps\\LC_MESSAGES\\*.mo")),
+		("i18n/pt/LC_MESSAGES",	glob.glob("i18n\\pt\\LC_MESSAGES\\*.mo")),
+		("i18n/pt_BR/LC_MESSAGES", glob.glob("i18n\\pt_BR\\LC_MESSAGES\\*.mo")),
+		("i18n/ru/LC_MESSAGES",	glob.glob("i18n\\ru\\LC_MESSAGES\\*.mo")),
+		("i18n/sk/LC_MESSAGES",	glob.glob("i18n\\sk\\LC_MESSAGES\\*.mo")),
+		("i18n/sr/LC_MESSAGES",	glob.glob("i18n\\sr\\LC_MESSAGES\\*.mo")),
 		("i18n/sv/LC_MESSAGES",	glob.glob("i18n\\sv\\LC_MESSAGES\\*.mo")),
 		("i18n/tr/LC_MESSAGES",	glob.glob("i18n\\tr\\LC_MESSAGES\\*.mo")),
-		("i18n/pt_BR/LC_MESSAGES", glob.glob("i18n\\pt_BR\\LC_MESSAGES\\*.mo")),
+		("i18n/uk/LC_MESSAGES",	glob.glob("i18n\\uk\\LC_MESSAGES\\*.mo")),
 		("i18n/zh_CN/LC_MESSAGES", glob.glob("i18n\\zh_CN\\LC_MESSAGES\\*.mo")),
 		("lib/plugins", glob.glob("lib\\plugins\\*.*")),
 		("lib/plugins/export", glob.glob("lib\\plugins\\export\\*.*")),
